@@ -94,7 +94,7 @@ def try_upsert(collection: StandardCollection, record_batch: RecordBatch, force=
                 ingested_documents.labels(region_label, tenant_label, fabric_label, workflow_label).inc()
                 ingested_bytes.labels(region_label, tenant_label, fabric_label, workflow_label).inc(len(json.dumps(r)))
                 # Update ingest_lag metric
-                diff = datetime.now() - datetime.fromisoformat(to_insert[i]["time_extracted"])
+                diff = datetime.utcnow() - datetime.strptime(to_insert[i]["time_extracted"], "%Y-%m-%dT%H:%M:%S.%fZ")
                 ingest_lag.labels(region_label, tenant_label, fabric_label, workflow_label).set(diff.total_seconds())
 
         if len(to_update) > 0:
@@ -105,7 +105,7 @@ def try_upsert(collection: StandardCollection, record_batch: RecordBatch, force=
                     print(f'Failed to insert/update record: {to_update[i]}. {r}')
                 else:
                     # Update ingest_lag metric
-                    diff = datetime.now() - datetime.fromisoformat(to_update[i]["time_extracted"])
+                    diff = datetime.utcnow() - datetime.strptime(to_update[i]["time_extracted"], "%Y-%m-%dT%H:%M:%S.%fZ")
                     ingest_lag.labels(region_label, tenant_label, fabric_label, workflow_label).set(diff.total_seconds())
         record_batch.last_executed_time = datetime.now()
 
